# ipywidgets

 * [Documentation](https://ipywidgets.readthedocs.io/en/stable/)
 * [GitHub](https://github.com/jupyter-widgets/ipywidgets)

Ipywidgets is the Python library that connect to the Jupyter widgets that live in the browser. Jupyter widgets can be buttons, sliders, or anything that exposes something in the browser.

Solara can use almost all existing ipywidgets, from the core library that provides slider, to ipyvuetify that gives us rich UI elements to ipyvolume that gives us interactive 3d visualizations .
